# -*- coding: utf-8 -*-
#
# Copyright (c) 2007 by BlueDynamics Alliance, Klein & Partner KEG, Austria
#
# Zope Public License (ZPL)
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL). A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__author__ = """Jens Klein <jens@bluedynamics.com>"""
__docformat__ = 'plaintext'

import os, sys, code
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from Testing import ZopeTestCase
from Products.ZCatalog.Catalog import Catalog
from Products.PluginIndexes.DateIndex.DateIndex import DateIndex
from Products.DateRangeInRangeIndex.index import DateRangeInRangeIndex
from DateTime import DateTime

ZopeTestCase.installProduct('DateRangeInRangeIndex')

class DummyEvent(object):
    """some dummy with a start and end to index"""
    
    def __init__(self, id, start, end):
        self.id = id
        self.start = start
        self.end = end
        
class DRIRITestcase(ZopeTestCase.ZopeTestCase):
    """Base TestCase for DateRangeInRangeIndex."""
    
    def afterSetUp(self):
        """set up a base scenario"""
        self.app.catalog = Catalog()
        idxstart = DateIndex('start')
        idxend   = DateIndex('end')
        self.app.catalog.addIndex('start', idxstart)
        self.app.catalog.addIndex('end',   idxend)
        driri = DateRangeInRangeIndex('driri', 
                                      extra={'startindex':'start',
                                             'endindex':'end'},
                                      caller=self.app.catalog)
        self.app.catalog.addIndex('driri', driri)
        self.app.catalog.addColumn('id')
        
    def buildDummies(self, cases):
        """setup dummies"""
        dummies = {}
        for id in cases:
            dummy = DummyEvent(id, DateTime(cases[id][0]), 
                                   DateTime(cases[id][1]))
            dummies[id] = dummy
        return dummies
    
    def catalogDummies(self, dummies):
        for id in dummies:
            self.app.catalog.catalogObject(dummies[id], id)
            
    def idsOfBrainsSorted(self, brains):
        ids = [brain.id for brain in brains]
        ids.sort()
        return ids

    def interact(self, locals=None):
        """Provides an interactive shell aka console inside your testcase.

        It looks exact like in a doctestcase and you can copy and paste
        code from the shell into your doctest. The locals in the testcase are
        available, because you are _in_ the testcase.

        In your testcase or doctest you can invoke the shell at any point by
        calling::

            >>> self.interact( locals() )

        @param locals: passed to InteractiveInterpreter.__init__()
        """
        savestdout = sys.stdout
        sys.stdout = sys.stderr
        sys.stderr.write('='*70)
        console = code.InteractiveConsole(locals)
        console.interact("""
ZopeTestCase Interactive Console
(c) BlueDynamics Alliance, Austria - 2005-2007

Note: You have the same locals available as in your test-case.
""")
        sys.stdout.write('\nend of ZopeTestCase Interactive Console session\n')
        sys.stdout.write('='*70+'\n')
        sys.stdout = savestdout


def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(DRIRITestcase))
    return suite

if __name__ == '__main__':
    framework()


